.. django-phone-auth documentation master file, created by
   sphinx-quickstart on Tue Apr  6 20:52:19 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   installation
   configuration
   templates
   signals
   decorators
   mixins
   views

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
